doing a temp sleep for chart-helm-api-test pipeline script until SEBA-102 is resolved

Change-Id: I7c7ed67e295f8aee7075d4d4bec1157e112efc51
diff --git a/jjb/pipeline/chart-api-test-helm.groovy b/jjb/pipeline/chart-api-test-helm.groovy
index 8a650ce..a019a33 100644
--- a/jjb/pipeline/chart-api-test-helm.groovy
+++ b/jjb/pipeline/chart-api-test-helm.groovy
@@ -143,8 +143,8 @@
              exit 1
            fi
 
-           # wait for services to load
-           ./scripts/wait_for_jobs.sh
+           # wait for services to load - TEMP SLEEP
+           sleep 300
 
            echo "# Checking helm deployments"
            kubectl get pods